=======
History
=======


0.3.0 (2018-08-30)
-----------------

* Compose docstring from param docstrings

0.2.3 (2018-08-28)

* Better and passing tests.

0.2.2 (2018-08-27)
------------------

* More stringent enforcement of signatures including defaults. Fixed build.

0.1.0 (2018-04-25)
------------------

* First release on PyPI.
